@@ -11,12 +11,11 @@ use Carp;
 
 use 5.010;
 
-our $VERSION = '0.0387_01'; # VERSION
+our $VERSION = 0.01_01;
 
 has jid      => ( is => 'rw', required => 1 );
 has password => ( is => 'rw', required => 1 );
 has dest     => ( is => 'rw', required => 1 );
-has type     => ( is => 'rw', default  => 'normal' );
 
 sub notify {
   my $self = shift;
@@ -38,9 +37,8 @@ sub notify {
       MSG("Sending message to $dest");
       my $immsg = AnyEvent::XMPP::IM::Message->new(
         to      => $dest,
-        #subject => $info->{subject},
-        body    => $info->{message},
-        type    => $self->type,
+        subject => $info->{subject} . '  (' . $info->{from} . ')',
+        body    => $info->{message}
       );
       $immsg->send($con);
     },
